@@ -53,8 +53,8 @@ void mkinvitfile()
 	char name[22];
 	if (*this_tty || get_this_tty()) {
 		getfname(name, this_tty);
-		invit_fd = open(name, O_CREAT | O_RDONLY | O_NONBLOCK);
-		chmod(name, S_IREAD | S_IWRITE | S_IWGRP | S_IWOTH);
+		invit_fd = open(name, O_CREAT | O_RDONLY | O_NONBLOCK,
+				S_IREAD | S_IWRITE | S_IWGRP | S_IWOTH);
 	}
 }
 
